@@ -119,17 +119,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for kn ConsoleCLIDownload resources
-	knManifest, err := consoleclidownload.RawManifest(mgr.GetClient())
-	if err != nil {
-		return err
-	}
-
-	knResources := knManifest.Resources()
 	gvkToCCD := make(map[schema.GroupVersionKind]runtime.Object)
-	for i := range knResources {
-		resource := &knResources[i]
-		gvkToCCD[resource.GroupVersionKind()] = resource
-	}
 
 	// append ConsoleCLIDownload type as well to Watch for kn CCD CO
 	gvkToCCD[consolev1.GroupVersion.WithKind("ConsoleCLIDownload")] = &consolev1.ConsoleCLIDownload{}
@@ -196,10 +186,10 @@ func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *servingv1alp
 		r.configure,
 		r.ensureFinalizers,
 		r.ensureCustomCertsConfigMap,
-		r.installKnConsoleCLIDownload,
 		r.installKourier,
 		r.installDashboard,
 		r.ensureProxySettings,
+		r.installKnConsoleCLIDownload,
 	}
 	for _, stage := range stages {
 		if err := stage(instance); err != nil {
@@ -395,16 +385,16 @@ func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServin
 	}
 
 	log.Info("Running cleanup logic")
-	log.Info("Deleting kourier")
-	if err := kourier.Delete(instance, r.client, r.scheme); err != nil {
-		return fmt.Errorf("failed to delete kourier: %w", err)
-	}
-
 	log.Info("Deleting kn ConsoleCLIDownload")
 	if err := consoleclidownload.Delete(instance, r.client, r.scheme); err != nil {
 		return fmt.Errorf("failed to delete kn ConsoleCLIDownload: %w", err)
 	}
 
+	log.Info("Deleting kourier")
+	if err := kourier.Delete(instance, r.client, r.scheme); err != nil {
+		return fmt.Errorf("failed to delete kourier: %w", err)
+	}
+
 	log.Info("Deleting dashboard")
 	if err := dashboard.Delete(instance, r.client); err != nil {
 		return fmt.Errorf("failed to delete dashboard configmap: %w", err)
